@@ -3,8 +3,8 @@
 #' @description Convenient printing of time elapsed. A wrapper of
 #' \code{data.table::timetaken}, but showing the results more directly.
 #' @param expr Valid R expression to be timed.
-#' @return A character vector of the form HH:MM:SS,
-#' or SS.MMMsec if under 60 seconds. See examples.
+#' @return  A character vector of the form HH:MM:SS,
+#' or SS.MMMsec if under 60 seconds (invisibly for \code{show_time}). See examples.
 #' @seealso \code{\link[data.table]{timetaken}}, \code{\link[base]{system.time}}
 #' @examples
 #'
@@ -16,14 +16,16 @@
 #'     mutate_dt(one = 1)
 #' })
 #' res
-#' @export
 
-sys_time_print = function(expr){
-  started.at=proc.time()
-  eval(substitute(expr),envir = parent.frame())
-  paste("Finished in",timetaken(started.at))
+#' @export
+sys_time_print = function (expr) {
+  started.at = proc.time()
+  eval(substitute(expr), envir = parent.frame())
+  paste("# Finished in", timetaken(started.at))
 }
 
 
 
 
+
+
